package org.jboss.qa.brms.performance;

import org.drools.KnowledgeBase;
import org.drools.KnowledgeBaseConfiguration;
import org.drools.KnowledgeBaseFactory;
import org.drools.builder.KnowledgeBuilder;
import org.drools.builder.KnowledgeBuilderFactory;
import org.drools.builder.ResourceType;
import org.drools.conf.EventProcessingOption;
import org.drools.io.impl.ClassPathResource;
import org.drools.runtime.KnowledgeSessionConfiguration;
import org.drools.runtime.StatefulKnowledgeSession;
import org.drools.runtime.conf.ClockTypeOption;
import org.drools.runtime.rule.WorkingMemoryEntryPoint;
import org.jboss.qa.brms.performance.domain.NewCustomerEvent;
import org.jboss.qa.brms.performance.domain.TransactionCreatedEvent;
import org.junit.Test;

import javax.xml.transform.sax.SAXSource;
import java.util.ArrayList;
import java.util.List;

public class Drools5KBaseCreationTest {
    private static int LOOPS = 20;

    private KnowledgeBase kbase;

    @Test
    public void testCreateKBaseFromDslDslr() {
        for (int i = 0; i < LOOPS; i++) {
            executeOneLoop(i);
        }
    }

    private void createKBase(String dslName, String dslrName) {
        KnowledgeBuilder kbuilder = KnowledgeBuilderFactory.newKnowledgeBuilder();
        kbuilder.add(new ClassPathResource(dslName), ResourceType.DSL);
        kbuilder.add(new ClassPathResource(dslrName), ResourceType.DSLR);
        KnowledgeBaseConfiguration kbconf = KnowledgeBaseFactory.newKnowledgeBaseConfiguration();
        kbconf.setOption(EventProcessingOption.CLOUD);

        if (kbuilder.hasErrors()) {
            throw new RuntimeException(kbuilder.getErrors().toString());
        }

        kbase = KnowledgeBaseFactory.newKnowledgeBase(kbconf);
        kbase.addKnowledgePackages(kbuilder.getKnowledgePackages());
    }

    private void executeOneLoop(int loopNumber) {
        long start = System.nanoTime();
        createKBase("dsl-kbase-creation.dsl", "dslr-kbase-creation.dslr");
        long took = System.nanoTime() - start;
        System.out.println("Loop #" + loopNumber + "took " + took / 1000 / 1000 + "ms.");
        System.gc();
    }

}
